# Somax 2 Library

This package contains the Somax 2 python library. It is a part of the Somax 2 application distributed through the [Github repository](https://github.com/DYCI2/Somax2) or the [Ircam Forum page](https://forum.ircam.fr/projects/detail/somax-2/).

It is strongly recommended to use Somax through the MaxMSP interface (which is [thorougly documented](https://github.com/DYCI2/Somax2)), but it possible for experienced Somax users to use it as a standalone python library as a tool for generative composition. At the moment, no documentation for the standalone library exists. 

An undocumented pre-alpha release is available on PyPI.
